@@ -1,5 +1,5 @@
 from subprocess import call as subprocess_call
-from subprocess import Popen as subprocess_popen
+from subprocess import PIPE, Popen as subprocess_popen
 from zshpower.utils.catch import current_user, current_shell
 from snakypy import printer
 from snakypy.ansi import FG
@@ -19,3 +19,11 @@ def change_shell():
             subprocess_call(f"chsh -s $(which zsh) {current_user()}", shell=True)
         except KeyboardInterrupt:
             printer("Canceled by user", foreground=FG.WARNING)
+
+
+def systemctl_is_active(service):
+    process = subprocess_popen(
+        ["systemctl", "is-active", service], stdout=PIPE, universal_newlines=True
+    )
+    output, err = process.communicate()
+    return output.replace("\n", ""), err
